@@ -127,9 +127,15 @@ def test_get_indexes(faux_conn):
     client.tables.foo.clustering_fields = ["user_email", "store_code"]
 
     assert faux_conn.dialect.get_indexes(faux_conn, "foo") == [
-        dict(name="partition", column_names=["tm"], unique=False,),
         dict(
-            name="clustering", column_names=["user_email", "store_code"], unique=False,
+            name="partition",
+            column_names=["tm"],
+            unique=False,
+        ),
+        dict(
+            name="clustering",
+            column_names=["user_email", "store_code"],
+            unique=False,
         ),
     ]
 
