@@ -25,8 +25,7 @@ geoalchemy2 = pytest.importorskip("geoalchemy2")
 
 
 def test_geoalchemy2_core(faux_conn, last_query):
-    """Make sure GeoAlchemy 2 Core Tutorial works as adapted to only having geometry
-    """
+    """Make sure GeoAlchemy 2 Core Tutorial works as adapted to only having geometry"""
     conn = faux_conn
 
     # Create the Table
@@ -42,7 +41,8 @@ def test_geoalchemy2_core(faux_conn, last_query):
 
     conn.execute(
         lake_table.insert().values(
-            name="Majeur", geog="POLYGON((0 0,1 0,1 1,0 1,0 0))",
+            name="Majeur",
+            geog="POLYGON((0 0,1 0,1 1,0 1,0 0))",
         )
     )
 
@@ -132,7 +132,8 @@ def test_geoalchemy2_core(faux_conn, last_query):
 
     conn.execute(
         lake_table.insert().values(
-            name="test2", geog=WKT("POLYGON((1 0,3 0,3 2,1 2,1 0))"),
+            name="test2",
+            geog=WKT("POLYGON((1 0,3 0,3 2,1 2,1 0))"),
         )
     )
     last_query(
